@@ -1,3 +1,5 @@
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+
 import logging
 import os
 import sys
@@ -5,6 +7,7 @@ import traceback
 
 logger = logging.getLogger(__name__)
 
+
 class NotSoTuf(object):
     """There are 2 ways to load config.  The first was is during
     object initialization. The second way is later with :meth:`update_config`
@@ -65,7 +68,7 @@ class Config(dict):
     You can define the configuration options in the
     module that calls :meth:`from_object`.  It is also possible to tell it
     to use the same module and with that provide the configuration values
-    just before the call::
+    just before the call.
 
     Loading from modules, only uppercase keys are added to the config.
     This makes it possible to use lowercase values in the config file for
@@ -124,7 +127,7 @@ class STDError(Exception):
 class ClientException(STDError):
     """Raised for Client exceptions"""
     def __init__(self, *args, **kwargs):
-        super(CleintException, self).__init__(*args, **kwargs)
+        super(ClientException, self).__init__(*args, **kwargs)
 
 
 class ConfigException(STDError):
@@ -154,4 +157,10 @@ class PackageHandlerError(STDError):
 class UpdaterError(STDError):
     """Raised for Updater exceptions"""
     def __init__(self, *args, **kwargs):
-        super(UpdaterError, self).__init__(*args, **kwargs)
\ No newline at end of file
+        super(UpdaterError, self).__init__(*args, **kwargs)
+
+
+class UploaderError(STDError):
+    """Raised for Uploader exceptions"""
+    def __init__(self, *args, **kwargs):
+        super(UploaderError, self).__init__(*args, **kwargs)
