@@ -166,9 +166,10 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
 
         """
         try:
-            filename = self.json_data['y_data'][name][version]['filename']
+            filename = self.json_data['y_data'][name][version][self.plat]['filename']
             highest_version = self._get_highest_version(name)
         except Exception as e:
+            log.error(str(e), exc_info=True)
             log.warning('Supplied version number not found')
             return False
         if _version_string_to_tuple(highest_version) <= _version_string_to_tuple(version):
